--- @brief Sends a character to a random position in the current scene.
---
--- @details
--- This will generate a random position in the scene, and check if the position is within a
--- certain area around the character's current position, and if it's inside the scene's current
--- current way system's border. If those conditions are met, the character is sent to this
--- new position.
---
--- @param char The character to move
--- @param maxDistance A `t_point` value with the maximum allowed X and Y distance to the character's current position (to prevent the character from walking too far away)
function sendCharacterToRandomPosition(char, maxDistance)
    if char == emptyObject or char == nil then
        char = game.CurrentCharacter
    end

    local currentScene = game.CurrentScene
    local charPosition = char.Position
    local sceneSize = currentScene.Sprite:getSize()
    local currentWaySystemPoints = currentScene.CurrentWaySystem.Border

    local validPositionFound = false
    local position = { x = 0, y = 0}
    while not validPositionFound do
        -- New random position
        local randomPosition = { x = math.random(0, sceneSize.x), y = math.random(0, sceneSize.y) }

        -- Check distance of random position to char position
        if (math.abs(charPosition.x - randomPosition.x) <= maxDistance.x) and (math.abs(charPosition.y - randomPosition.y) <= maxDistance.y) then
            -- Check if random position is inside the walkable area
            if isPointInsidePolygon(randomPosition, currentWaySystemPoints) then
                position = randomPosition
                validPositionFound = true
            end
        end
    end

    -- Send character to new position
    char.Destination = position
end
   
registerActionPart('SENDCHARTORNDPOS', function(activeAction, actionPart)
    sendCharacterToRandomPosition(actionPart.Link, { x = actionPart.Int, y = actionPart.AltInt})
    return false
end)
